==> bladerf-2023.02-2-aarch64.pkg.tar.xz: usr/share/doc/libbladeRF/html/search/all_12.js <==
var searchData=
[
  ['sample_20rate_0',['Sample rate',['../group___f_n___s_a_m_p_l_i_n_g.html',1,'']]],
  ['sampling_20mux_1',['Sampling Mux',['../group___f_n___b_l_a_d_e_r_f1___s_a_m_p_l_i_n_g___m_u_x.html',1,'']]],
  ['scale_2',['scale',['../structbladerf__range.html#a1d28dec57cce925ad92342891bd71e7c',1,'bladerf_range']]],
  ['scheduled_20tuning_3',['Scheduled Tuning',['../group___f_n___s_c_h_e_d_u_l_e_d___t_u_n_i_n_g.html',1,'']]],
  ['scheduled_20tx_20bursts_4',['Synchronous Interface: Scheduled TX bursts',['../sync_tx_meta_bursts.html',1,'']]],
  ['selection_5',['Clock input selection',['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___c_l_o_c_k___b_u_f_f_e_r___s_e_l_e_c_t.html',1,'']]],
  ['serial_6',['serial',['../structbladerf__devinfo.html#abe126c2e73d5e14a30c3648521a9aee0',1,'bladerf_devinfo::serial'],['../structbladerf__serial.html#abe126c2e73d5e14a30c3648521a9aee0',1,'bladerf_serial::serial'],['../structbladerf__image.html#aaa74f66cc1ee926c3c8e871411c8fa5f',1,'bladerf_image::serial']]],
  ['set_20_5fgain_20range_20standardization_7',['bladerf_{get,set}_gain range standardization',['../relnotes_2_0.html#relnotes_2_0_api_gain',1,'']]],
  ['signal_8',['signal',['../structbladerf__trigger.html#a2bea7884d40e7f7af4a9e2fa9ca39661',1,'bladerf_trigger']]],
  ['significant_20changes_20to_20the_20libbladerf_20api_9',['Significant changes to the libbladeRF API',['../relnotes_2_0.html#relnotes_2_0_api',1,'']]],
  ['smb_20clock_20port_20control_10',['SMB clock port control',['../group___f_n___s_m_b___c_l_o_c_k.html',1,'']]],
  ['spdt_11',['spdt',['../structbladerf__quick__tune.html#a77be955e492f82e89eea9cc2d5696f85',1,'bladerf_quick_tune']]],
  ['specific_20api_12',['specific api',['../group___b_l_a_d_e_r_f1.html',1,'bladeRF1-specific API'],['../group___b_l_a_d_e_r_f2.html',1,'bladeRF2-specific API']]],
  ['spi_20flash_13',['SPI Flash',['../group___f_n___s_p_i___f_l_a_s_h.html',1,'']]],
  ['stage_20control_14',['Individual gain stage control',['../relnotes_2_0.html#relnotes_2_0_feats_gc_manual',1,'']]],
  ['stages_20deprecated_15',['Gain stages (deprecated)',['../group___f_n___b_l_a_d_e_r_f1___g_a_i_n.html',1,'']]],
  ['standardization_16',['bladerf_{get,set}_gain range standardization',['../relnotes_2_0.html#relnotes_2_0_api_gain',1,'']]],
  ['status_17',['status',['../relnotes_2_0.html#relnotes_2_0_feats_hw_power',1,'Power status'],['../structbladerf__metadata.html#ade20423e91627f07e610924cb0081623',1,'bladerf_metadata::status']]],
  ['step_18',['step',['../structbladerf__range.html#aa8630add62fc7df3a4559bd728d7f9b8',1,'bladerf_range']]],
  ['streaming_19',['Streaming',['../group___s_t_r_e_a_m_i_n_g.html',1,'']]],
  ['streaming_20api_20changes_20for_20mimo_20',['Streaming API changes for MIMO',['../relnotes_2_0.html#relnotes_2_0_api_stream',1,'']]],
  ['structure_20and_20flags_21',['Metadata structure and flags',['../group___s_t_r_e_a_m_i_n_g___f_o_r_m_a_t___m_e_t_a_d_a_t_a.html',1,'']]],
  ['support_22',['support',['../group___f_n___x_b.html',1,'Expansion board support'],['../group___f_n___b_l_a_d_e_r_f1___x_b.html',1,'Expansion board support'],['../relnotes_2_0.html#relnotes_2_0_feats_platform',1,'Multiple platform support']]],
  ['switching_20control_23',['RF Switching Control',['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___r_f___s_w_i_t_c_h_i_n_g.html',1,'']]],
  ['synchronous_20api_24',['Synchronous API',['../group___f_n___s_t_r_e_a_m_i_n_g___s_y_n_c.html',1,'']]],
  ['synchronous_20interface_3a_20basic_20usage_20without_20metadata_25',['bladeRF Synchronous Interface: Basic Usage Without Metadata',['../sync_no_meta.html',1,'']]],
  ['synchronous_20interface_3a_20rx_20with_20metadata_26',['Synchronous Interface: RX with Metadata',['../sync_rx_meta.html',1,'']]],
  ['synchronous_20interface_3a_20scheduled_20tx_20bursts_27',['Synchronous Interface: Scheduled TX bursts',['../sync_tx_meta_bursts.html',1,'']]],
  ['synth_20control_28',['Phase Detector/Freq. Synth Control',['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___p_l_l.html',1,'']]],
  ['system_20gain_20proportioning_29',['System gain proportioning',['../relnotes_2_0.html#relnotes_2_0_feats_gc_proportioning',1,'']]]
];

==> bladerf-2024.05-1-aarch64.pkg.tar.xz: usr/share/doc/libbladeRF/html/search/all_12.js <==
var searchData=
[
  ['sample_20rate_0',['Sample rate',['../group___f_n___s_a_m_p_l_i_n_g.html',1,'']]],
  ['sampling_20mux_1',['Sampling Mux',['../group___f_n___b_l_a_d_e_r_f1___s_a_m_p_l_i_n_g___m_u_x.html',1,'']]],
  ['scale_2',['scale',['../structbladerf__range.html#a1d28dec57cce925ad92342891bd71e7c',1,'bladerf_range']]],
  ['scheduled_20tuning_3',['Scheduled Tuning',['../group___f_n___s_c_h_e_d_u_l_e_d___t_u_n_i_n_g.html',1,'']]],
  ['scheduled_20tx_20bursts_4',['Synchronous Interface: Scheduled TX bursts',['../sync_tx_meta_bursts.html',1,'']]],
  ['selection_5',['Clock input selection',['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___c_l_o_c_k___b_u_f_f_e_r___s_e_l_e_c_t.html',1,'']]],
  ['serial_6',['serial',['../structbladerf__devinfo.html#abe126c2e73d5e14a30c3648521a9aee0',1,'bladerf_devinfo::serial'],['../structbladerf__serial.html#abe126c2e73d5e14a30c3648521a9aee0',1,'bladerf_serial::serial'],['../structbladerf__image.html#aaa74f66cc1ee926c3c8e871411c8fa5f',1,'bladerf_image::serial']]],
  ['set_20_5fgain_20range_20standardization_7',['bladerf_{get,set}_gain range standardization',['../relnotes_2_0.html#relnotes_2_0_api_gain',1,'']]],
  ['signal_8',['signal',['../structbladerf__trigger.html#a2bea7884d40e7f7af4a9e2fa9ca39661',1,'bladerf_trigger']]],
  ['significant_20changes_20to_20the_20libbladerf_20api_9',['Significant changes to the libbladeRF API',['../relnotes_2_0.html#relnotes_2_0_api',1,'']]],
  ['smb_20clock_20port_20control_10',['SMB clock port control',['../group___f_n___s_m_b___c_l_o_c_k.html',1,'']]],
  ['spdt_11',['spdt',['../structbladerf__quick__tune.html#a77be955e492f82e89eea9cc2d5696f85',1,'bladerf_quick_tune']]],
  ['specific_20api_12',['specific API',['../group___b_l_a_d_e_r_f1.html',1,'bladeRF1-specific API'],['../group___b_l_a_d_e_r_f2.html',1,'bladeRF2-specific API']]],
  ['spi_20flash_13',['SPI Flash',['../group___f_n___s_p_i___f_l_a_s_h.html',1,'']]],
  ['stage_20control_14',['Individual gain stage control',['../relnotes_2_0.html#relnotes_2_0_feats_gc_manual',1,'']]],
  ['stages_20deprecated_15',['Gain stages (deprecated)',['../group___f_n___b_l_a_d_e_r_f1___g_a_i_n.html',1,'']]],
  ['standardization_16',['bladerf_{get,set}_gain range standardization',['../relnotes_2_0.html#relnotes_2_0_api_gain',1,'']]],
  ['status_17',['status',['../relnotes_2_0.html#relnotes_2_0_feats_hw_power',1,'Power status'],['../structbladerf__metadata.html#ade20423e91627f07e610924cb0081623',1,'bladerf_metadata::status']]],
  ['step_18',['step',['../structbladerf__range.html#aa8630add62fc7df3a4559bd728d7f9b8',1,'bladerf_range']]],
  ['streaming_19',['Streaming',['../group___s_t_r_e_a_m_i_n_g.html',1,'']]],
  ['streaming_20api_20changes_20for_20mimo_20',['Streaming API changes for MIMO',['../relnotes_2_0.html#relnotes_2_0_api_stream',1,'']]],
  ['structure_20and_20flags_21',['Metadata structure and flags',['../group___s_t_r_e_a_m_i_n_g___f_o_r_m_a_t___m_e_t_a_d_a_t_a.html',1,'']]],
  ['support_22',['support',['../group___f_n___x_b.html',1,'Expansion board support'],['../group___f_n___b_l_a_d_e_r_f1___x_b.html',1,'Expansion board support'],['../relnotes_2_0.html#relnotes_2_0_feats_platform',1,'Multiple platform support']]],
  ['switching_20control_23',['RF Switching Control',['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___r_f___s_w_i_t_c_h_i_n_g.html',1,'']]],
  ['synchronous_20api_24',['Synchronous API',['../group___f_n___s_t_r_e_a_m_i_n_g___s_y_n_c.html',1,'']]],
  ['synchronous_20interface_3a_20basic_20usage_20without_20metadata_25',['bladeRF Synchronous Interface: Basic Usage Without Metadata',['../sync_no_meta.html',1,'']]],
  ['synchronous_20interface_3a_20rx_20with_20metadata_26',['Synchronous Interface: RX with Metadata',['../sync_rx_meta.html',1,'']]],
  ['synchronous_20interface_3a_20scheduled_20tx_20bursts_27',['Synchronous Interface: Scheduled TX bursts',['../sync_tx_meta_bursts.html',1,'']]],
  ['synth_20control_28',['Phase Detector/Freq. Synth Control',['../group___f_n___b_l_a_d_e_r_f2___l_o_w___l_e_v_e_l___p_l_l.html',1,'']]],
  ['system_20gain_20proportioning_29',['System gain proportioning',['../relnotes_2_0.html#relnotes_2_0_feats_gc_proportioning',1,'']]]
];
